function [call,put] = kirk(K, S1, S2, sigma1, sigma2, rho, r, T)
    % K = strike price
    % S1 = spot price for asset 1
    % S2 = spot price for asset 2
    % sigma1 = volatility for asset 1
    % sigma2 = volatility for asset 2
    % rho = correlation between assets
    % r = risk-free rate
    % T = time to maturity

    frac1 = S1/(S2+K) ;
    frac2 = S2/(S2+K) ;
    sigma = sqrt(sigma1^2 + sigma2^2*frac2^2 - 2*rho*sigma1*sigma2*frac2) ;
    
    d1 = (log(frac1) + 0.5*(sigma^2)*T)/(sigma*sqrt(T)) ;
    d2 = (log(frac1) - 0.5*(sigma^2)*T)/(sigma*sqrt(T)) ;
    
    call = (S2+K)*(exp(-r*T)*(frac1*normcdf(d1) - normcdf(d2))) ;
    put = (S2+K)*(exp(-r*T)*(normcdf(-d2) - frac1*normcdf(-d1))) ;
end